==> lxqt-powermanagement_2.1.0.orig.tar.xz: lxqt-powermanagement-2.1.0/config/translations/lxqt-config-powermanagement_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>电池监视器设置</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>开启电池监视器(&amp;N)</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>警告:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>电量不足临界值:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>图标:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>正在充电</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>正在放电</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>电量不足时:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>显示图标:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>来自主题</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>圆环</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>带百分比的圆环</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>带百分比的电池和背景</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>带百分比的电池</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>内置</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>百分比: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>开启空闲监视器(&amp;L)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>空闲临界时间:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>启用背光修改</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>电池闲置时：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>电池闲置时间：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>背光 (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>分钟：秒钟</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>在交流电闲置时：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>交流闲置时间：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>分钟：秒（分钟：01：30）</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>检测背光</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>电池放电 </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>全屏时禁用空闲检查</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>开启屏盖监视器(&amp;L)</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>合盖时的动作:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>电池供电时:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>无动作</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>交流供电时:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>使用外置监视器时(&amp;U)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>电源管理设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>电池</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>屏盖</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>电源键</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>表单</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>处理电源键</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>电源键的动作:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>挂起键的动作:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>Hibernate 的按键操作:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.cpp" line="48"/>
        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
        <translation>注意：在 Wayland 下，电源键由合成器配置。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>无动作</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>提问</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>关闭显示器(s)</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement-2.3.0.tar.xz: lxqt-powermanagement-2.3.0/config/translations/lxqt-config-powermanagement_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>电池监视器设置</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>开启电池监视器(&amp;N)</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>警告:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>电量不足临界值:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>图标:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>正在充电</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>正在放电</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>电量不足时:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>显示图标:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>来自主题</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>圆环</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>带百分比的圆环</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>带百分比的电池和背景</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>带百分比的电池</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>built in</source>
        <translation>内置</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="114"/>
        <source>Level: %1%</source>
        <translation>百分比: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>开启空闲监视器(&amp;L)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>空闲临界时间:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>启用背光修改</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>电池闲置时：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="93"/>
        <source>Battery Idle time:</source>
        <translation>电池闲置时间：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>背光 (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>分钟：秒钟</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="113"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>在交流电闲置时：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>交流闲置时间：</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="100"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>分钟：秒（分钟：01：30）</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="195"/>
        <source>Check backlight</source>
        <translation>检测背光</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>On battery discharging </source>
        <translation>电池放电 </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Command to Turn off Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="214"/>
        <source>Recommended command for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="234"/>
        <source>On Wayland, usually handled by compositor and app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="237"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>全屏时禁用空闲检查</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>开启屏盖监视器(&amp;L)</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>合盖时的动作:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>电池供电时:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>无动作</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>交流供电时:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>使用外置监视器时(&amp;U)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>电源管理设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Battery</source>
        <translation>电池</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <source>Lid</source>
        <translation>屏盖</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="64"/>
        <source>Power keys</source>
        <translation>电源键</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>表单</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>处理电源键</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>电源键的动作:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>挂起键的动作:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>Hibernate 的按键操作:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.cpp" line="50"/>
        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
        <translation>注意：在 Wayland 下，电源键由合成器配置。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>无动作</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>提问</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>关闭显示器(s)</translation>
    </message>
</context>
</TS>
